import setuptools 
setuptools.setup(
    name="torch-ort-inference",
    version="100.0.5",
    author="Alon walker",
    author_email="alonwalker@facebook.com",
    description="torch-ort-inference of torch-ort-inference of torch-ort-inference",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ]
)
